plugins {
    id("java")
    id("org.jetbrains.intellij") version "1.17.1"
    id("org.jetbrains.kotlin.jvm") version "1.9.22"
    id("jacoco")
    id("com.github.kt3k.coveralls") version "2.12.2"
}

group = "de.platon42"
version = "1.14"

repositories {
    mavenCentral()
}

/*
  To run tests in IntelliJ use these VM Options for run configuration
  -ea -Didea.system.path=build/idea-sandbox/system-test -Didea.config.path=build/idea-sandbox/config-test -Didea.plugins.path=build/idea-sandbox/plugins-test
 */

dependencies {
    //implementation "org.jetbrains.kotlin:kotlin-stdlib-jdk8"
    testImplementation("org.assertj:assertj-core:3.25.3")
    testImplementation("org.assertj:assertj-guava:3.25.3")
    testImplementation("org.junit.jupiter:junit-jupiter-api:5.10.2")
    testRuntimeOnly("org.junit.jupiter:junit-jupiter-engine:5.10.2")
    testImplementation("org.jetbrains.kotlin:kotlin-test")
    testImplementation("org.jetbrains.kotlin:kotlin-reflect")
    testImplementation("org.junit.platform:junit-platform-launcher:1.10.2")
//    testImplementation "org.jetbrains.kotlin:kotlin-test-junit"
}

intellij {
    version.set("2022.2") // LATEST-EAP-SNAPSHOT
    //pluginName.set(provider { 'Concise AssertJ Optimizing Nitpicker (Cajon)' })
    updateSinceUntilBuild.set(false)
    plugins.set(listOf("com.intellij.java"))
}

tasks {
    withType<JavaCompile> {
        sourceCompatibility = "11"
        targetCompatibility = "11"
    }
    withType<org.jetbrains.kotlin.gradle.tasks.KotlinCompile> {
        kotlinOptions.jvmTarget = "11"
    }

    test {
        useJUnitPlatform()
        testLogging {
            events("passed", "skipped", "failed")
        }
    }


    prepareSandbox {
        enabled = true
    }

    verifyPlugin {
        enabled = true
    }

    verifyPluginConfiguration {
        enabled = true
    }

    patchPluginXml {
        enabled = true
        sinceBuild.set("222")
        changeNotes.set(
            """
  <h4>V1.14 (19-Feb-24)</h4>
    <ul>
      <li>Now requires minimum version 2022.2.
      <li>Maintenance. Updated various dependencies (Kotlin 1.9.22) and AssertJ 3.25.3 and AssertJ-Guava 3.25.3.
      <li>Reworked JUnit 5 test framework to work again. However, all the tests are broken.
      I spent several days trying to figure out what is going on, but I'm giving up on this pile of crap called IntelliJ. 
      Jetbrains keeps breaking the APIs and implementations every year and I just cannot be bothered anymore.
      <li>This is very likely the last version.
    </ul>
  <h4>V1.13 (18-Aug-22)</h4>
    <ul>
      <li>API change in IntelliJ platforms now requires minimum version 2019.3.1. Sorry, giving up to maintain compatibility after four attempts.
      <li>Maintenance. Updated various dependencies (Kotlin 1.7.10) and AssertJ 3.23.1 and AssertJ-Guava 3.5.0.
      <li>Tried to fix unreproducible issue #9.
      <li>Added AssertThatIsZeroOne inspection demanded by issue #5.
      <li>Fix for wrongly joining statements that cannot be trivially joined (e.g. with filteredOn). Fixes issue #6.
    </ul>
  <p>Full changelog available at <a href="https://git.platon42.de/chrisly42/cajon-plugin#changelog">Gitea project site</a>.</p>
"""
        )
    }

    publishPlugin {
        token.set(System.getProperty("org.gradle.project.intellijPublishToken"))
    }

    runIde {
        enabled = true
        if (project.hasProperty("ideDir")) {
            ideDir.set(file(project.property("ideDir")!!))
            jbrVersion.set(project.property("ideJBR")!! as String)
        }
        autoReloadPlugins.set(false)
    }


    runPluginVerifier {
        ideVersions.set(listOf("IC-222.4167.29", "IC-233.14015.106")) // 2022.2.2 - 2023.3.3
        downloadDir.set(System.getenv("user.home") + "/.gradle/caches/modules-2/files-2.1/com.jetbrains.intellij.idea/verifier")
    }


}

//tasks.coveralls {
//    dependsOn(jacocoTestReport)
//}

//jacoco {
//    toolVersion = '0.8.8'
//}
//
//jacocoTestReport {
//    reports {
//        xml.required.set(true)
//        csv.required.set(false)
//    }
//}
