package de.platon42.intellij.jupiter

import com.intellij.testFramework.TestLoggerFactory
import com.intellij.testFramework.fixtures.IdeaTestExecutionPolicy
import com.intellij.testFramework.runInEdtAndWait
import org.junit.jupiter.api.extension.ExtensionContext
import org.junit.jupiter.api.extension.InvocationInterceptor
import org.junit.jupiter.api.extension.ReflectiveInvocationContext
import java.lang.reflect.Method

class EdtInterceptorExtension : InvocationInterceptor {

    override fun interceptTestMethod(
        invocation: InvocationInterceptor.Invocation<Void>,
        invocationContext: ReflectiveInvocationContext<Method>,
        extensionContext: ExtensionContext
    ) {
        val throwables = arrayOfNulls<Throwable>(1)

        val runnable = Runnable {
            try {
                TestLoggerFactory.onTestStarted()
                invocation.proceed()
                TestLoggerFactory.onTestFinished(true, extensionContext.displayName)
            } catch (e: Throwable) {
                TestLoggerFactory.onTestFinished(false, extensionContext.displayName)
                throwables[0] = e
            }
        }

        invokeTestRunnable(runnable)

        if (throwables[0] != null) {
            throw throwables[0]!!
        }
    }

    companion object {
        private fun invokeTestRunnable(runnable: Runnable) {
            val policy = IdeaTestExecutionPolicy.current()
            if (policy != null && !policy.runInDispatchThread()) {
                runnable.run()
            } else {
                runInEdtAndWait {
                    runnable.run()
                }
            }
        }
    }
}
