package de.platon42.intellij.plugins.cajon

import com.intellij.codeInsight.intention.IntentionAction
import com.intellij.pom.java.LanguageLevel
import de.platon42.intellij.jupiter.AbstractJUnit5TestCase
import de.platon42.intellij.jupiter.AddLocalJarToModule
import de.platon42.intellij.jupiter.TestDataPath
import de.platon42.intellij.jupiter.TestJdk
import org.assertj.core.api.Assertions
import org.assertj.core.api.Assertions.assertThat
import org.assertj.core.api.Condition
import org.junit.jupiter.api.DisplayNameGeneration
import org.junit.jupiter.api.DisplayNameGenerator
import java.lang.reflect.Method

@TestDataPath("src/test/resources")
@TestJdk(LanguageLevel.JDK_1_8)
@AddLocalJarToModule(Assertions::class)
//@AddMavenDependencyToModule("org.assertj:assertj-core:3.25.3", includeTransitiveDependencies = false, DependencyScope.COMPILE)
@DisplayNameGeneration(AbstractCajonTest.CutOffFixtureDisplayNameGenerator::class)
abstract class AbstractCajonTest : AbstractJUnit5TestCase() {

    protected fun executeQuickFixes(regex: Regex, expectedFixes: Int) {
        val quickfixes = getQuickFixes(regex, expectedFixes)
        assertThat(quickfixes.groupBy { it.familyName }).hasSize(1)
        quickfixes.forEach(fixture::launchAction)
    }

    protected fun executeQuickFixesNoFamilyNameCheck(regex: Regex, expectedFixes: Int) {
        val quickfixes = getQuickFixes(regex, expectedFixes)
        quickfixes.forEach(fixture::launchAction)
    }

    protected fun getQuickFixes(regex: Regex, expectedFixes: Int): List<IntentionAction> {
        val allFixes = fixture.getAllQuickFixes()
        val quickfixes = allFixes.filter { it.text.matches(regex) }
        assertThat(quickfixes).`as`("Fixes matched by $regex: ${allFixes.map { it.text }}").hasSize(expectedFixes)
        return quickfixes
    }

    protected fun assertHighlightings(count: Int, snippet: String) {
        assertThat(fixture.doHighlighting())
            .areExactly(count, Condition({ it.description?.contains(snippet) ?: false }, "containing"))
    }

    class CutOffFixtureDisplayNameGenerator : DisplayNameGenerator.ReplaceUnderscores() {
        override fun generateDisplayNameForMethod(testClass: Class<*>?, testMethod: Method?): String {
            val nameForMethod = super.generateDisplayNameForMethod(testClass, testMethod)
            return nameForMethod.substringBefore("$")
        }
    }
}
