package de.platon42.intellij.plugins.cajon.inspections

import de.platon42.intellij.jupiter.AddMavenDependencyToModule
import de.platon42.intellij.jupiter.TestDataSubPath
import de.platon42.intellij.plugins.cajon.AbstractCajonTest
import org.junit.jupiter.api.Test

@AddMavenDependencyToModule("org.assertj:assertj-guava:3.25.3")
@TestDataSubPath("inspections/GuavaOptional")
internal class AssertThatGuavaOptionalInspectionTest : AbstractCajonTest() {

    @Test
    internal fun assertThat_get_or_isPresent_for_Guava_Optional_can_be_simplified() {
        fixture.enableInspections(AssertThatGuavaOptionalInspection::class.java)
        fixture.configureByFile("GuavaOptionalBefore.java")
        executeQuickFixes(Regex.fromLiteral("Remove isPresent() of actual expression and use assertThat().isPresent() instead"), 6)
        executeQuickFixes(Regex.fromLiteral("Remove isPresent() of actual expression and use assertThat().isAbsent() instead"), 5)
        executeQuickFixes(Regex.fromLiteral("Remove orNull() of actual expression and use assertThat().isPresent() instead"), 2)
        executeQuickFixes(Regex.fromLiteral("Remove orNull() of actual expression and use assertThat().isAbsent() instead"), 2)
        executeQuickFixes(Regex.fromLiteral("Remove get() of actual expression and use assertThat().contains() instead"), 1)
        executeQuickFixes(Regex.fromLiteral("Unwrap expected expression and replace isEqualTo() with contains()"), 6)
        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with Guava assertThat().isAbsent()"), 3)
        executeQuickFixes(Regex.fromLiteral("Replace isNotEqualTo() with Guava assertThat().isPresent()"), 3)
        fixture.checkResultByFile("GuavaOptionalAfter.java")
    }

    @Test
    internal fun adds_missing_Guava_import_any_order() {
        fixture.enableInspections(AssertThatGuavaOptionalInspection::class.java)
        fixture.configureByFile("WithoutPriorGuavaImportBefore.java")
        executeQuickFixesNoFamilyNameCheck(Regex(".*eplace .* with .*"), 4)
        executeQuickFixesNoFamilyNameCheck(Regex("Remove .*"), 3)
        fixture.checkResultByFile("WithoutPriorGuavaImportAfter.java")
    }

    @Test
    internal fun adds_missing_Guava_import_isAbsent_first() {
        fixture.enableInspections(AssertThatGuavaOptionalInspection::class.java)
        fixture.configureByFile("WithoutPriorGuavaImportBefore.java")
        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with Guava assertThat().isAbsent()"), 1)
        executeQuickFixesNoFamilyNameCheck(Regex(".*eplace .* with .*"), 3)
        executeQuickFixesNoFamilyNameCheck(Regex("Remove .*"), 3)
        fixture.checkResultByFile("WithoutPriorGuavaImportAfter.java")
    }
}
