package de.platon42.intellij.plugins.cajon.inspections

import de.platon42.intellij.jupiter.TestDataSubPath
import de.platon42.intellij.plugins.cajon.AbstractCajonTest
import org.junit.jupiter.api.Test

@TestDataSubPath("inspections/Size")
internal class AssertThatSizeInspectionTest : AbstractCajonTest() {

    @Test
    internal fun assertThat_size_of_array_collection_or_map_can_be_simplified() {
        fixture.enableInspections(AssertThatSizeInspection::class.java)
        fixture.configureByFile("SizeBefore.java")
        assertHighlightings(1, "Try to operate on the iterable itself rather than its size")

        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with isEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isZero() with isEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isNotZero() with isNotEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isGreaterThan() with isNotEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isGreaterThanOrEqualTo() with isNotEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isLessThan() with isEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isLessThanOrEqualTo() with isEmpty()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with hasSameSizeAs()"), 15)
        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with hasSize()"), 15)
        executeQuickFixes(Regex.fromLiteral("Replace isGreaterThan() with hasSizeGreaterThan()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isGreaterThanOrEqualTo() with hasSizeGreaterThanOrEqualTo()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isLessThan() with hasSizeLessThan()"), 5)
        executeQuickFixes(Regex.fromLiteral("Replace isLessThanOrEqualTo() with hasSizeLessThanOrEqualTo()"), 5)
        executeQuickFixes(Regex.fromLiteral("Remove size determination of expected expression and replace hasSize() with hasSameSizeAs()"), 17)
        fixture.checkResultByFile("SizeAfter.java")
    }
}
