package de.platon42.intellij.plugins.cajon.inspections

import de.platon42.intellij.jupiter.TestDataSubPath
import de.platon42.intellij.plugins.cajon.AbstractCajonTest
import org.assertj.core.api.Assertions.assertThat
import org.assertj.core.api.extrakting
import org.junit.jupiter.api.Test

@TestDataSubPath("inspections/StringIsEmpty")
internal class AssertThatStringIsEmptyInspectionTest : AbstractCajonTest() {

    @Test
    internal fun assertThat_with_isEqualTo_emptyString_can_use_isEmpty() {
        fixture.enableInspections(AssertThatStringIsEmptyInspection::class.java)
        fixture.configureByFile("StringIsEmptyBefore.java")
        val highlights = fixture.doHighlighting()
            .asSequence()
            .filter { it.description?.contains(" can be simplified to") ?: false }
            .toList()
        assertThat(highlights).hasSize(6).extrakting { it.text }.doesNotContain("assertThat")
        executeQuickFixes(Regex.fromLiteral("Replace isEqualTo() with isEmpty()"), 3)
        executeQuickFixes(Regex.fromLiteral("Replace hasSize() with isEmpty()"), 3)
        fixture.checkResultByFile("StringIsEmptyAfter.java")
    }
}
